==> finaluna-api-3.0.0.zip: finaluna-api/sources/jp/finaluna/api/type/CollectionFactory.java <==
/*
 * Copyright (C) 2010 NTT DATA Corporation.
 */
package jp.finaluna.api.type;

/**
 * Finaluna^𐶐ׂ̃t@NgB
 * 
 * <p>
 * ƖWbNNXFinaluna^tB[hɊi[CX^X́AConstantFactroyNXpĐB
 * </p>
 * 
 * <pre>
 * )
 * public class Blogic impliments logic {
 * private MapType stringCode = VariableFactory.createMapType();
 * </pre>
 * 
 * @author NTTf[^
 * @version $Revision: 38309 $ $Date: 2010-03-18 17:14:55 +0900 $
 * 
 */
@Rcsid("$Revision: 38309 $ $Date: 2010-03-18 17:14:55 +0900 $")
public class CollectionFactory {
    /**
     * Finaluna^NXB
     */
    private static CollectionFactoryDelegate typeFactory = null;

    /**
     * ftHgRXgN^
     */
    private CollectionFactory() {
        super();
    }

    /**
     * Finaluna^NXݒ肷B
     * 
     * @param factory ConstantFactoryDelegate
     */
    public static void setTypeFactory(CollectionFactoryDelegate factory) {
        typeFactory = factory;
    }

    /**
     * ListType̎擾B
     * <p>
     * e10̑̌^Xg^𐶐B
     * <p>
     * 
     * @param <E> Gg
     * @return Xg^
     */
    public static < E > ListType < E > createListType() {
        return typeFactory.createListType();
    }

    /**
     * ListType̎擾B
     * <p>
     * w肵eʂ̑̌^Xg^𐶐B eʂ̒l̏ꍇAFinalunaSysExceptionX[B
     * <p>
     * 
     * @param <E> Gg
     * @param initialCapacity Xg̏e
     * @return Xg^
     */
    public static < E > ListType < E > createListType(int initialCapacity) {
        return typeFactory.createListType(initialCapacity);
    }

    /**
     * SetType̎擾B
     * <p>
     * e16̑̌^̃Zbg^𐶐B
     * <p>
     * 
     * @param <E> Gg
     * @return Zbg^
     */
    public static < E > SetType < E > createSetType() {
        return typeFactory.createSetType();
    }

    /**
     * SetType̎擾B
     * <p>
     * w肵eʂ̑̌^Zbg^𐶐B eʂ̒l̏ꍇAFinalunaSysExceptionX[B
     * <p>
     * 
     * @param <E> Gg
     * @param initialCapacity Zbg̏e
     * @return Zbg^
     */
    public static < E > SetType < E > createSetType(int initialCapacity) {
        return typeFactory.createSetType(initialCapacity);
    }

    /**
     * MapType̎擾B
     * <p>
     * e16̑̌^}bv^𐶐B
     * <p>
     * 
     * @param <K> }bṽL[l
     * @param <V> }bv̒l
     * @return }bv^
     */
    public static < K, V > MapType < K, V > createMapType() {
        return typeFactory.createMapType();
    }

    /**
     * MapType̎擾B
     * <p>
     * w肵eʂ̑̌^}bv^𐶐B eʂ̒l̏ꍇAFinalunaSysExceptionX[B
     * <p>
     * 
     * @param <K> }bṽL[l
     * @param <V> }bv̒l
     * @param initialCapacity }bv̏e
     * @return }bv^
     */
    public static < K, V > MapType < K, V > createMapType(int initialCapacity) {
        return typeFactory.createMapType(initialCapacity);
    }
}

==> finaluna-api-3.1.0.zip: finaluna-api/sources/jp/finaluna/api/type/CollectionFactory.java <==
/*
 * Copyright (C) 2010 NTT DATA Corporation.
 */
package jp.finaluna.api.type;

/**
 * Finaluna^𐶐ׂ̃t@NgB
 * 
 * <p>
 * ƖWbNNXFinaluna^tB[hɊi[CX^X́ACollectionFactoryNXpĐB
 * </p>
 * 
 * <pre>
 * )
 * public class Blogic impliments logic {
 * private MapType stringCode = VariableFactory.createMapType();
 * </pre>
 * 
 * @author NTTf[^
 * @version $Revision: 47846 $ $Date: 2010-10-14 11:44:47 +0900 $
 * 
 */
@Rcsid("$Revision: 47846 $ $Date: 2010-10-14 11:44:47 +0900 $")
public class CollectionFactory {
    /**
     * Finaluna^NXB
     */
    private static CollectionFactoryDelegate typeFactory = null;

    /**
     * ftHgRXgN^
     */
    private CollectionFactory() {
        super();
    }

    /**
     * Finaluna^NXݒ肷B
     * 
     * @param factory ConstantFactoryDelegate
     */
    public static void setTypeFactory(CollectionFactoryDelegate factory) {
        typeFactory = factory;
    }

    /**
     * ListType̎擾B
     * <p>
     * e10̑̌^Xg^𐶐B
     * <p>
     * 
     * @param <E> Gg
     * @return Xg^
     */
    public static < E > ListType < E > createListType() {
        return typeFactory.createListType();
    }

    /**
     * ListType̎擾B
     * <p>
     * w肵eʂ̑̌^Xg^𐶐B eʂ̒l̏ꍇAFinalunaSysExceptionX[B
     * <p>
     * 
     * @param <E> Gg
     * @param initialCapacity Xg̏e
     * @return Xg^
     */
    public static < E > ListType < E > createListType(int initialCapacity) {
        return typeFactory.createListType(initialCapacity);
    }

    /**
     * SetType̎擾B
     * <p>
     * e16̑̌^̃Zbg^𐶐B
     * <p>
     * 
     * @param <E> Gg
     * @return Zbg^
     */
    public static < E > SetType < E > createSetType() {
        return typeFactory.createSetType();
    }

    /**
     * SetType̎擾B
     * <p>
     * w肵eʂ̑̌^Zbg^𐶐B eʂ̒l̏ꍇAFinalunaSysExceptionX[B
     * <p>
     * 
     * @param <E> Gg
     * @param initialCapacity Zbg̏e
     * @return Zbg^
     */
    public static < E > SetType < E > createSetType(int initialCapacity) {
        return typeFactory.createSetType(initialCapacity);
    }

    /**
     * MapType̎擾B
     * <p>
     * e16̑̌^}bv^𐶐B
     * <p>
     * 
     * @param <K> }bṽL[l
     * @param <V> }bv̒l
     * @return }bv^
     */
    public static < K, V > MapType < K, V > createMapType() {
        return typeFactory.createMapType();
    }

    /**
     * MapType̎擾B
     * <p>
     * w肵eʂ̑̌^}bv^𐶐B eʂ̒l̏ꍇAFinalunaSysExceptionX[B
     * <p>
     * 
     * @param <K> }bṽL[l
     * @param <V> }bv̒l
     * @param initialCapacity }bv̏e
     * @return }bv^
     */
    public static < K, V > MapType < K, V > createMapType(int initialCapacity) {
        return typeFactory.createMapType(initialCapacity);
    }
}
